# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: WorkerBroker.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='WorkerBroker.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x12WorkerBroker.proto\"\xc4\x01\n\x13ReportStatusRequest\x12\x15\n\rclientAddress\x18\x01 \x01(\t\x12\x31\n\x06status\x18\x02 \x01(\x0e\x32!.ReportStatusRequest.WorkerStatus\x12\x0f\n\x07message\x18\x03 \x01(\t\"R\n\x0cWorkerStatus\x12\x0b\n\x07Pending\x10\x00\x12\x0b\n\x07Running\x10\x01\x12\r\n\tCompleted\x10\x02\x12\x0b\n\x07\x46\x61ulted\x10\x03\x12\x0c\n\x08\x43\x61nceled\x10\x04\"\x07\n\x05\x45mpty\"@\n\x15ReportProgressRequest\x12\x15\n\rclientAddress\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x01\x32n\n\x0cWorkerBroker\x12,\n\x0cReportStatus\x12\x14.ReportStatusRequest\x1a\x06.Empty\x12\x30\n\x0eReportProgress\x12\x16.ReportProgressRequest\x1a\x06.Emptyb\x06proto3'
)


_REPORTSTATUSREQUEST_WORKERSTATUS = _descriptor.EnumDescriptor(
    name='WorkerStatus',
    full_name='ReportStatusRequest.WorkerStatus',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='Pending', index=0, number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name='Running', index=1, number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name='Completed', index=2, number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name='Faulted', index=3, number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
            name='Canceled', index=4, number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=137,
    serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_REPORTSTATUSREQUEST_WORKERSTATUS)


_REPORTSTATUSREQUEST = _descriptor.Descriptor(
    name='ReportStatusRequest',
    full_name='ReportStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='clientAddress', full_name='ReportStatusRequest.clientAddress', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='status', full_name='ReportStatusRequest.status', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='ReportStatusRequest.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
        _REPORTSTATUSREQUEST_WORKERSTATUS,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=23,
    serialized_end=219,
)


_EMPTY = _descriptor.Descriptor(
    name='Empty',
    full_name='Empty',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=221,
    serialized_end=228,
)


_REPORTPROGRESSREQUEST = _descriptor.Descriptor(
    name='ReportProgressRequest',
    full_name='ReportProgressRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='clientAddress', full_name='ReportProgressRequest.clientAddress', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='progress', full_name='ReportProgressRequest.progress', index=1,
            number=2, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=230,
    serialized_end=294,
)

_REPORTSTATUSREQUEST.fields_by_name['status'].enum_type = _REPORTSTATUSREQUEST_WORKERSTATUS
_REPORTSTATUSREQUEST_WORKERSTATUS.containing_type = _REPORTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ReportStatusRequest'] = _REPORTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['ReportProgressRequest'] = _REPORTPROGRESSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportStatusRequest = _reflection.GeneratedProtocolMessageType('ReportStatusRequest', (_message.Message,), {
    'DESCRIPTOR': _REPORTSTATUSREQUEST,
    '__module__': 'WorkerBroker_pb2'
    # @@protoc_insertion_point(class_scope:ReportStatusRequest)
})
_sym_db.RegisterMessage(ReportStatusRequest)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR': _EMPTY,
    '__module__': 'WorkerBroker_pb2'
    # @@protoc_insertion_point(class_scope:Empty)
})
_sym_db.RegisterMessage(Empty)

ReportProgressRequest = _reflection.GeneratedProtocolMessageType('ReportProgressRequest', (_message.Message,), {
    'DESCRIPTOR': _REPORTPROGRESSREQUEST,
    '__module__': 'WorkerBroker_pb2'
    # @@protoc_insertion_point(class_scope:ReportProgressRequest)
})
_sym_db.RegisterMessage(ReportProgressRequest)


_WORKERBROKER = _descriptor.ServiceDescriptor(
    name='WorkerBroker',
    full_name='WorkerBroker',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=296,
    serialized_end=406,
    methods=[
        _descriptor.MethodDescriptor(
            name='ReportStatus',
            full_name='WorkerBroker.ReportStatus',
            index=0,
            containing_service=None,
            input_type=_REPORTSTATUSREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ReportProgress',
            full_name='WorkerBroker.ReportProgress',
            index=1,
            containing_service=None,
            input_type=_REPORTPROGRESSREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_WORKERBROKER)

DESCRIPTOR.services_by_name['WorkerBroker'] = _WORKERBROKER

# @@protoc_insertion_point(module_scope)
